'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AlertProps = undefined;

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _CloseOutlined = require('@ant-design/icons-vue/CloseOutlined');

var _CloseOutlined2 = _interopRequireDefault(_CloseOutlined);

var _CheckCircleOutlined = require('@ant-design/icons-vue/CheckCircleOutlined');

var _CheckCircleOutlined2 = _interopRequireDefault(_CheckCircleOutlined);

var _ExclamationCircleOutlined = require('@ant-design/icons-vue/ExclamationCircleOutlined');

var _ExclamationCircleOutlined2 = _interopRequireDefault(_ExclamationCircleOutlined);

var _InfoCircleOutlined = require('@ant-design/icons-vue/InfoCircleOutlined');

var _InfoCircleOutlined2 = _interopRequireDefault(_InfoCircleOutlined);

var _CloseCircleOutlined = require('@ant-design/icons-vue/CloseCircleOutlined');

var _CloseCircleOutlined2 = _interopRequireDefault(_CloseCircleOutlined);

var _CheckCircleFilled = require('@ant-design/icons-vue/CheckCircleFilled');

var _CheckCircleFilled2 = _interopRequireDefault(_CheckCircleFilled);

var _ExclamationCircleFilled = require('@ant-design/icons-vue/ExclamationCircleFilled');

var _ExclamationCircleFilled2 = _interopRequireDefault(_ExclamationCircleFilled);

var _InfoCircleFilled = require('@ant-design/icons-vue/InfoCircleFilled');

var _InfoCircleFilled2 = _interopRequireDefault(_InfoCircleFilled);

var _CloseCircleFilled = require('@ant-design/icons-vue/CloseCircleFilled');

var _CloseCircleFilled2 = _interopRequireDefault(_CloseCircleFilled);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _BaseMixin = require('../_util/BaseMixin');

var _BaseMixin2 = _interopRequireDefault(_BaseMixin);

var _vueTypes = require('../_util/vue-types');

var _vueTypes2 = _interopRequireDefault(_vueTypes);

var _getTransitionProps = require('../_util/getTransitionProps');

var _getTransitionProps2 = _interopRequireDefault(_getTransitionProps);

var _propsUtil = require('../_util/props-util');

var _vnode = require('../_util/vnode');

var _configProvider = require('../config-provider');

var _base = require('../base');

var _base2 = _interopRequireDefault(_base);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function noop() {}

var iconMapFilled = {
  success: _CheckCircleFilled2['default'],
  info: _InfoCircleFilled2['default'],
  error: _CloseCircleFilled2['default'],
  warning: _ExclamationCircleFilled2['default']
};

var iconMapOutlined = {
  success: _CheckCircleOutlined2['default'],
  info: _InfoCircleOutlined2['default'],
  error: _CloseCircleOutlined2['default'],
  warning: _ExclamationCircleOutlined2['default']
};

var AlertProps = exports.AlertProps = {
  /**
   * Type of Alert styles, options:`success`, `info`, `warning`, `error`
   */
  type: _vueTypes2['default'].oneOf(['success', 'info', 'warning', 'error']),
  /** Whether Alert can be closed */
  closable: _vueTypes2['default'].bool,
  /** Close text to show */
  closeText: _vueTypes2['default'].any,
  /** Content of Alert */
  message: _vueTypes2['default'].any,
  /** Additional content of Alert */
  description: _vueTypes2['default'].any,
  /** Callback when close Alert */
  // onClose?: React.MouseEventHandler<HTMLAnchorElement>;
  /** Trigger when animation ending of Alert */
  afterClose: _vueTypes2['default'].func.def(noop),
  /** Whether to show icon */
  showIcon: _vueTypes2['default'].bool,
  prefixCls: _vueTypes2['default'].string,
  banner: _vueTypes2['default'].bool,
  icon: _vueTypes2['default'].any
};

var Alert = {
  name: 'AAlert',
  props: AlertProps,
  mixins: [_BaseMixin2['default']],
  inject: {
    configProvider: { 'default': function _default() {
        return _configProvider.ConfigConsumerProps;
      } }
  },
  data: function data() {
    return {
      closing: false,
      closed: false
    };
  },

  methods: {
    handleClose: function handleClose(e) {
      e.preventDefault();
      var dom = this.$el;
      dom.style.height = dom.offsetHeight + 'px';
      // Magic code
      // 重复一次后才能正确设置 height
      dom.style.height = dom.offsetHeight + 'px';

      this.setState({
        closing: true
      });
      this.$emit('close', e);
    },
    animationEnd: function animationEnd() {
      this.setState({
        closing: false,
        closed: true
      });
      this.afterClose();
    }
  },

  render: function render(h) {
    var _classNames;

    var customizePrefixCls = this.prefixCls,
        banner = this.banner,
        closing = this.closing,
        closed = this.closed;

    var getPrefixCls = this.configProvider.getPrefixCls;
    var prefixCls = getPrefixCls('alert', customizePrefixCls);

    var closable = this.closable,
        type = this.type,
        showIcon = this.showIcon;

    var closeText = (0, _propsUtil.getComponentFromProp)(this, 'closeText');
    var description = (0, _propsUtil.getComponentFromProp)(this, 'description');
    var message = (0, _propsUtil.getComponentFromProp)(this, 'message');
    var icon = (0, _propsUtil.getComponentFromProp)(this, 'icon');
    // banner模式默认有 Icon
    showIcon = banner && showIcon === undefined ? true : showIcon;
    // banner模式默认为警告
    type = banner && type === undefined ? 'warning' : type || 'info';

    var iconType = (description ? iconMapOutlined : iconMapFilled)[type] || null;

    // closeable when closeText is assigned
    if (closeText) {
      closable = true;
    }

    var alertCls = (0, _classnames2['default'])(prefixCls, (_classNames = {}, (0, _defineProperty3['default'])(_classNames, prefixCls + '-' + type, true), (0, _defineProperty3['default'])(_classNames, prefixCls + '-closing', closing), (0, _defineProperty3['default'])(_classNames, prefixCls + '-with-description', !!description), (0, _defineProperty3['default'])(_classNames, prefixCls + '-no-icon', !showIcon), (0, _defineProperty3['default'])(_classNames, prefixCls + '-banner', !!banner), (0, _defineProperty3['default'])(_classNames, prefixCls + '-closable', closable), _classNames));

    var closeIcon = closable ? h(
      'a',
      {
        attrs: { type: 'button', tabIndex: 0 },
        on: {
          'click': this.handleClose
        },
        'class': prefixCls + '-close-icon' },
      [closeText ? h(
        'span',
        { 'class': prefixCls + '-close-text' },
        [closeText]
      ) : h(_CloseOutlined2['default'])]
    ) : null;

    var iconNode = icon && ((0, _propsUtil.isValidElement)(icon) ? (0, _vnode.cloneElement)(icon, {
      'class': prefixCls + '-icon'
    }) : h(
      'span',
      { 'class': prefixCls + '-icon' },
      [icon]
    )) || h(iconType, { 'class': prefixCls + '-icon' });

    var transitionProps = (0, _getTransitionProps2['default'])(prefixCls + '-slide-up', {
      appear: false,
      afterLeave: this.animationEnd
    });
    return closed ? null : h(
      'transition',
      transitionProps,
      [h(
        'div',
        {
          directives: [{
            name: 'show',
            value: !closing
          }],
          'class': alertCls, attrs: { 'data-show': !closing }
        },
        [showIcon ? iconNode : null, h(
          'span',
          { 'class': prefixCls + '-message' },
          [message]
        ), h(
          'span',
          { 'class': prefixCls + '-description' },
          [description]
        ), closeIcon]
      )]
    );
  }
};

/* istanbul ignore next */
Alert.install = function (Vue) {
  Vue.use(_base2['default']);
  Vue.component(Alert.name, Alert);
};

exports['default'] = Alert;